@@ -12,20 +12,20 @@ Yahoo::Marketing - an interface for Yahoo! Search Marketing's Web Services.
 
 =head1 VERSION
 
-Version 2.01
+Version 3.01
 
 =cut
 
 # not using 3 part version #s, 
 # see http://www.perlmonks.org/?node_id=520850
-our $VERSION = '2.02';
+our $VERSION = '3.01';
 
 
 =head1 SYNOPSIS
 
 This collection of modules makes interacting with Yahoo! Search Marketing's Web Services as easy as possible.
 
-B<Note that this version (2.x) is intended to be used with V2 of the marketing web services.>
+B<Note that this version (3.x) is intended to be used with V3 of the marketing web services.>
 
 Sample Usage:
 
@@ -69,7 +69,7 @@ Sample Usage:
 
 =head1 VERSIONING
 
-This version of Yahoo::Marketing is intended to be used with V2 of Yahoo's Marketing API.  If you need to access both V1 and V2 simultaneously, you'll need to install 2 versions of Yahoo::Marketing.  In order to have 2 versions of the same perl module installed, you'll need to put one in a non-standard location, for example ~/perl/.  See perldoc CPAN for more information.
+This version of Yahoo::Marketing is intended to be used with V3 of Yahoo's Marketing API.  If you need to access both V2 and V3 simultaneously, you'll need to install 2 versions of Yahoo::Marketing.  In order to have 2 versions of the same perl module installed, you'll need to put one in a non-standard location, for example ~/perl/.  See perldoc CPAN for more information.
 
 =head1 OVERVIEW
 
@@ -276,22 +276,24 @@ is loaded B<only if an account has not already been set!>
  ---
  default:
    default_account: 12345678
-   endpoint: https://endpoint.host:port/services
+   endpoint: https://endpoint.host/services
+   vault_endpoint: https://vault.endpoint.host/services
    license: your-ews-license
    master_account: 98765432
    password: secretpassword
-   uri: http://marketing.ews.yahooapis.com/V2
+   uri: http://marketing.ews.yahooapis.com/V3
    username: defaultusername
-   version: V2
+   version: V3
  sandbox:
    default_account: 21921327 
    endpoint: https://sandbox.marketing.ews.yahooapis.com/services
+   vault_endpoint: https://sandboxvault.marketing.ews.yahooapis.com/services
    license: 90837ada-3b26-c2e5-6d59-61d7f2fb578e
    master_account: 21921326 
    password: mypassword
-   uri: http://marketing.ews.yahooapis.com/V2
+   uri: http://marketing.ews.yahooapis.com/V3
    username: mytestusername
-   version: V2
+   version: V3
 
 
 =head1 DEBUGGING
