@@ -1,5 +1,5 @@
 package Yahoo::Marketing::RangeDefinitionType;
-# Copyright (c) 2006 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2007 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -31,25 +31,6 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
                          );
 
 
-sub _new_from_hash {
-    my ( $self, $hash ) = @_;
-
-    my $obj = __PACKAGE__->new;
-    foreach my $key ( keys %$hash ) {
-        if ( $key eq 'bucket' ) {
-            my @array;
-            foreach my $item ( ref $hash->{$key}{'BucketType'} eq 'ARRAY' ? @{ $hash->{ $key }{'BucketType'} } : ( $hash->{ $key }{'BucketType'} || () ) ) {
-                my $bucket_type = Yahoo::Marketing::BucketType->new->_new_from_hash( $item );
-                push @array, $bucket_type;
-            }
-            $obj->$key( @array ? \@array : undef );
-        }
-        else {
-            $obj->$key( $hash->{ $key } );
-        }
-    }
-    return $obj;
-}
 
 1;
 =head1 SYNOPSIS
